# Change Log

## [v0.1.1](https://github.com/mcs07/MolVS/tree/v0.1.1) (2018-04-11)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.1.0...v0.1.1)

**Implemented enhancements:**

- Add hydrogen to REMOVE\_FRAGMENTS list [\#23](https://github.com/mcs07/MolVS/pull/23) ([JoshuaMeyers](https://github.com/JoshuaMeyers))

**Fixed bugs:**

- Fluorine considered metal [\#24](https://github.com/mcs07/MolVS/issues/24)
- Fix mistake in metal SMARTS [\#25](https://github.com/mcs07/MolVS/pull/25) ([mcs07](https://github.com/mcs07))

**Closed issues:**

- MolVS 0.1.0 Standardization fails on Python 3 [\#22](https://github.com/mcs07/MolVS/issues/22)
- molvs hugs on some molecules [\#21](https://github.com/mcs07/MolVS/issues/21)

## [v0.1.0](https://github.com/mcs07/MolVS/tree/v0.1.0) (2018-02-07)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.9...v0.1.0)

**Implemented enhancements:**

- Add support for using conda in development [\#19](https://github.com/mcs07/MolVS/pull/19) ([mcs07](https://github.com/mcs07))

**Fixed bugs:**

- error standardizing ionization [\#15](https://github.com/mcs07/MolVS/issues/15)
- Molecule did not standardise overnight [\#14](https://github.com/mcs07/MolVS/issues/14)
- Problem with \_\_repr\_\_ method of TautomerTransform class [\#7](https://github.com/mcs07/MolVS/issues/7)
- Fixed forced charge corrections [\#18](https://github.com/mcs07/MolVS/pull/18) ([mcs07](https://github.com/mcs07))
- Fixing infinite loop issue in reionization code [\#17](https://github.com/mcs07/MolVS/pull/17) ([coleb](https://github.com/coleb))
- Fix TautomerTransform repr - fixes \#7 [\#8](https://github.com/mcs07/MolVS/pull/8) ([mcs07](https://github.com/mcs07))

## [v0.0.9](https://github.com/mcs07/MolVS/tree/v0.0.9) (2017-01-27)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.8...v0.0.9)

## [v0.0.8](https://github.com/mcs07/MolVS/tree/v0.0.8) (2016-12-12)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.7...v0.0.8)

**Fixed bugs:**

- Standardizer gets stuck on a molecule [\#4](https://github.com/mcs07/MolVS/issues/4)
- Fix reionizer infinite loop - fixes \#4 [\#5](https://github.com/mcs07/MolVS/pull/5) ([mcs07](https://github.com/mcs07))

## [v0.0.7](https://github.com/mcs07/MolVS/tree/v0.0.7) (2016-12-04)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.6...v0.0.7)

## [v0.0.6](https://github.com/mcs07/MolVS/tree/v0.0.6) (2016-12-04)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.5...v0.0.6)

## [v0.0.5](https://github.com/mcs07/MolVS/tree/v0.0.5) (2016-02-15)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.4...v0.0.5)

## [v0.0.4](https://github.com/mcs07/MolVS/tree/v0.0.4) (2016-01-05)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.3...v0.0.4)

## [v0.0.3](https://github.com/mcs07/MolVS/tree/v0.0.3) (2014-08-19)
[Full Changelog](https://github.com/mcs07/MolVS/compare/v0.0.2...v0.0.3)

## [v0.0.2](https://github.com/mcs07/MolVS/tree/v0.0.2) (2014-08-06)
